%global realname riak
%global upstream basho
#
# This package contains only arch-independent data but install it into
# arch-dependent directory thus making this package arch-dependent. In order to
# suppress empty *-debuginfo generation we have to explicitly order
# debuginfo-generator to skip trying to build *-debuiginfo for that package.
#
%global debug_package %{nil}
%global git_tag c315dc9
%global patchnumber 0


%define lock_version() %{1}%{?_isa} = %(rpm -q --queryformat "%{VERSION}" %{1})


Name:		riak
Version:	1.3.2
Release:	2%{?dist}
Summary:	Dynamo-inspired key/value store
Group:		Applications/Databases
License:	ASL 2.0
URL:		http://wiki.basho.com/Riak.html
VCS:		https://github.com/basho/riak.git
# wget --content-disposition https://github.com/basho/riak/tarball/riak-1.3.2
Source0:	%{upstream}-%{realname}-riak-%{version}-%{patchnumber}-g%{git_tag}.tar.gz
Source1:	%{name}.tmpfiles.conf
Source2:	%{name}.init
Source3:	%{name}.service
Patch1:		%{name}-0001-Rename-basho-patches-directory.patch
Patch2:		%{name}-0002-Don-t-require-specific-Erlang-OTP-version.patch
Patch3:		%{name}-0003-Relax-version-deps.patch
Patch4:		%{name}-0004-Temporarily-disable-lager_syslog-backend.patch
Patch5:		%{name}-0005-Remove-additional-search-paths.patch
Patch6:		%{name}-0006-Don-t-use-versioned-path-for-escript.patch
Patch7:		%{name}-0007-Install-nodetool-into-bindir-and-add-prefix.patch
Patch8:		%{name}-0008-Don-t-use-versioned-path-for-run_erl.patch
Patch9:		%{name}-0009-Don-t-use-versioned-path-for-erl.patch
Patch10:	%{name}-0010-Don-t-use-versioned-path-for-to_erl.patch
Patch11:	%{name}-0011-Don-t-hardcode-path-to-erlexec.patch
Patch12:	%{name}-0012-Remove-unused-environment-variables.patch
BuildRequires:	erlang-rebar
BuildRequires:	erlang-cluster_info
BuildRequires:	erlang-ebloom
BuildRequires:	erlang-eper
BuildRequires:	erlang-riak_control
BuildRequires:	erlang-riak_kv
BuildRequires:	erlang-riak_search
BuildRequires:	erlang-riaknostic

#
# Ordinary runtime dependencies
#

Requires:	erlang-bear%{?_isa}
Requires:	erlang-bitcask%{?_isa} >= 1.6.0
Requires:	erlang-ebloom%{?_isa}
Requires:	erlang-eper%{?_isa}
Requires:	erlang-erlydtl%{?_isa}
Requires:	erlang-folsom%{?_isa}
Requires:	erlang-js%{?_isa}
Requires:	erlang-mochiweb%{?_isa}
Requires:	erlang-poolboy%{?_isa}
Requires:	erlang-protobuffs%{?_isa}
Requires:	erlang-sext%{?_isa} >= 1.1

#
# These packages are tightl ycoupled to the core and
# must be a strict dependencies
#

Requires:	%lock_version erlang-basho_stats
Requires:	%lock_version erlang-cluster_info
Requires:	%lock_version erlang-eleveldb
Requires:	%lock_version erlang-lager
# FIXME - I'll add luwak backend later
#Requires:	%lock_version erlang-luwak
Requires:	%lock_version erlang-merge_index
Requires:	%lock_version erlang-riak_api
Requires:	%lock_version erlang-riak_control
Requires:	%lock_version erlang-riak_core
Requires:	%lock_version erlang-riak_err
Requires:	%lock_version erlang-riak_kv
Requires:	%lock_version erlang-riak_pb
Requires:	%lock_version erlang-riak_pipe
Requires:	%lock_version erlang-riak_search
Requires:	%lock_version erlang-riak_sysmon
Requires:	%lock_version erlang-riaknostic

%if 0%{?el5}%{?el6}
# Require initscripts on old systemd
Requires(post): chkconfig
Requires(preun): chkconfig initscripts
%endif

# Users and groups
Requires(pre): shadow-utils


%description
Riak is a Dynamo-inspired key/value store that scales predictably and easily.
Riak also simplifies development by giving developers the ability to quickly
prototype, test, and deploy their applications.

A truly fault-tolerant system, Riak has no single point of failure. No machines
are special or central in Riak, so developers and operations professionals can
decide exactly how fault-tolerant they want and need their applications to be.


%prep
%setup -q -n %{upstream}-%{realname}-51ccac6
%patch1 -p1 -b .basho-patches-rename
%patch2 -p1 -b .r16b
%patch3 -p1 -b .relax_deps
%patch4 -p1 -b .disable_lager_syslog
%patch5 -p1 -b .remove_search_paths
%patch6 -p1 -b .fix_escript
%patch7 -p1 -b .fix_nodetool
%patch8 -p1 -b .run_erl
%patch9 -p1 -b .erl
%patch10 -p1 -b .to_erl
%patch11 -p1 -b .erlexec
%patch12 -p1 -b .cleanup

gzip -d doc/man/man1/*.1.gz
sed -i -e "s,\\\n,,g" doc/man/man1/riak-admin.1

# Override the default vars.config with platform specific settings
cat > rel/vars.config <<EOF
% Platform-specific installation paths
{platform_bin_dir,	"%{_bindir}"}.
{platform_data_dir,	"%{_localstatedir}/lib/%{name}"}.
{platform_etc_dir,	"%{_sysconfdir}/%{name}"}.
{platform_lib_dir,	"%{_libdir}/%{name}"}.
{platform_log_dir,	"%{_localstatedir}/log/%{name}"}.

%%
%% etc/app.config
%%
{web_ip,		"127.0.0.1"}.
{web_port,		8098}.
{handoff_port,		8099}.
{pb_ip,			"127.0.0.1"}.
{pb_port,		8087}.
{ring_state_dir,	"%{_localstatedir}/lib/%{name}/ring"}.
{bitcask_data_root,	"%{_localstatedir}/lib/%{name}/bitcask"}.
{leveldb_data_root,	"%{_localstatedir}/lib/%{name}/leveldb"}.
{sasl_error_log,	"%{_localstatedir}/log/%{name}/sasl-error.log"}.
{sasl_log_dir,		"%{_localstatedir}/log/%{name}/sasl"}.
{mapred_queue_dir,	"%{_localstatedir}/lib/%{name}/mr_queue"}.

%% riak_search
{merge_index_data_root,	"%{_localstatedir}/lib/%{name}/merge_index"}.

%% lager
{lager_handlers, "[ \
                           {lager_file_backend, [ \
                               {\"{{platform_log_dir}}/error.log\", error, 10485760, \"$D0\", 5}, \
                               {\"{{platform_log_dir}}/console.log\", info, 10485760, \"$D0\", 5} \
                           ]} \
                       ]"}.


%% Javascript VMs
{map_js_vms,	8}.
{reduce_js_vms,	6}.
{hook_js_vms,	2}.

%%
%% etc/vm.args
%%
{node,		"riak@127.0.0.1"}.
{crash_dump,	"%{_localstatedir}/log/%{name}/erl_crash.dump"}.

%%
%% bin/riak
%%
{runner_script_dir,	"%{_bindir}"}.
{runner_base_dir,	"%{_libdir}/%{name}"}.
{runner_etc_dir,	"%{_sysconfdir}/%{name}"}.
{runner_log_dir,	"%{_localstatedir}/log/%{name}"}.
{pipe_dir,		"%{_localstatedir}/run/%{name}/"}.
{runner_user,		"%{name}"}.
EOF


%build
rebar compile generate -v


%install
# Install Erlang VM config files
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
install -D -p -m 0644 rel/%{name}/etc/app.config %{buildroot}%{_sysconfdir}/%{name}/app.config
install -D -p -m 0644 rel/%{name}/etc/vm.args %{buildroot}%{_sysconfdir}/%{name}/vm.args

# Install init-script or systemd-service
%if 0%{?el5}%{?el6}
install -D -p -m 0755 %{SOURCE2} %{buildroot}%{_initrddir}/%{name}
%else
install -D -p -m 644 %{SOURCE1} %{buildroot}/usr/lib/tmpfiles.d/%{name}.conf
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service
%endif

# Install runtime scripts
install -p -m 0755 -D  rel/%{name}/bin/%{name} %{buildroot}%{_bindir}/%{name}
install -p -m 0755 -D  rel/%{name}/bin/%{name}-admin %{buildroot}%{_bindir}/%{name}-admin
install -p -m 0755 -D  rel/%{name}/bin/search-cmd %{buildroot}%{_bindir}/search-cmd

# Install man-pages
install -d %{buildroot}%{_mandir}/man1/
install -p -m 0644 doc/man/man1/%{name}.1 %{buildroot}%{_mandir}/man1/
install -p -m 0644 doc/man/man1/%{name}-admin.1 %{buildroot}%{_mandir}/man1/
install -p -m 0644 doc/man/man1/search-cmd.1 %{buildroot}%{_mandir}/man1/

# Install remaining Erlang files
mkdir -p %{buildroot}%{_libdir}/erlang/lib/%{name}-%{version}/ebin
install -p -m 0644 ebin/%{name}.app %{buildroot}%{_libdir}/erlang/lib/%{name}-%{version}/ebin/
install -p -m 0644 ebin/etop_txt.beam %{buildroot}%{_libdir}/erlang/lib/%{name}-%{version}/ebin/

# Make room for temporary files, logs, and data
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/bitcask/
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/dets/
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/leveldb/
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/merge_index/
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/mr_queue/
mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}/ring/
mkdir -p %{buildroot}/%{_localstatedir}/log/%{name}/
mkdir -p %{buildroot}/%{_localstatedir}/log/%{name}/sasl/
mkdir -p %{buildroot}/%{_localstatedir}/run/%{name}/

# Install Erlang release binary data
mkdir -p %{buildroot}/%{_libdir}/%{name}/releases/%{version}/
install -m 644 rel/%{name}/releases/RELEASES %{buildroot}/%{_libdir}/%{name}/releases/
install -m 644 rel/%{name}/releases/start_erl.data %{buildroot}/%{_libdir}/%{name}/releases/
install -m 644 rel/%{name}/releases/%{version}/%{name}.boot %{buildroot}/%{_libdir}/%{name}/releases/%{version}/
install -m 644 rel/%{name}/releases/%{version}/%{name}.rel %{buildroot}/%{_libdir}/%{name}/releases/%{version}/
install -m 644 rel/%{name}/releases/%{version}/%{name}.script %{buildroot}/%{_libdir}/%{name}/releases/%{version}/
install -m 644 rel/%{name}/releases/%{version}/start_clean.boot %{buildroot}/%{_libdir}/%{name}/releases/%{version}/
install -m 644 rel/%{name}/releases/%{version}/start_clean.rel %{buildroot}/%{_libdir}/%{name}/releases/%{version}/
install -m 644 rel/%{name}/releases/%{version}/start_clean.script %{buildroot}/%{_libdir}/%{name}/releases/%{version}/

# Install nodetool
install -D -p -m 755 rel/%{name}/erts-*/bin/nodetool %{buildroot}/%{_bindir}/%{name}-nodetool

# Make compat symlinks
cd %{buildroot}/%{_libdir}/%{name}
ln -s %{_libdir}/erlang/lib lib


%pre
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
useradd -r -g %{name} -d %{_localstatedir}/run/%{name} -s /sbin/nologin \
-c "Riak - a dynamo-inspired key/value store" %{name} 2>/dev/null || :


%post
%if 0%{?el5}%{?el6}
/sbin/chkconfig --add %{name}
%else
%systemd_post %{name}.service
%endif


%preun
%if 0%{?el5}%{?el6}
if [ $1 = 0 ]; then
 /sbin/service %{name} stop > /dev/null 2>&1
 /sbin/chkconfig --del %{name}
fi
%else
%systemd_preun %{name}.service
%endif


%files
%doc doc/[abdr]* releasenotes/ LICENSE NOTICE README.org RELEASE-NOTES.md THANKS
%if 0%{?el5}%{?el6}
%{_initrddir}/%{name}
%else
/usr/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%endif
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/app.config
%config(noreplace) %{_sysconfdir}/%{name}/vm.args
%{_bindir}/%{name}
%{_bindir}/%{name}-admin
%{_bindir}/%{name}-nodetool
%{_bindir}/search-cmd
%dir %{_libdir}/erlang/lib/%{name}-%{version}
%dir %{_libdir}/erlang/lib/%{name}-%{version}/ebin
%{_libdir}/erlang/lib/%{name}-%{version}/ebin/%{name}.app
%{_libdir}/erlang/lib/%{name}-%{version}/ebin/etop_txt.beam
%{_mandir}/man1/%{name}.1.gz
%{_mandir}/man1/%{name}-admin.1.gz
%{_mandir}/man1/search-cmd.1.gz
%{_libdir}/%{name}/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/bitcask/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/dets/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/leveldb/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/merge_index/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/mr_queue/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/lib/%{name}/ring/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/log/%{name}/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/log/%{name}/sasl/
%dir %attr(0755, %{name}, %{name}) %{_localstatedir}/run/%{name}/


%changelog
* Mon Oct 28 2013 Peter Lemenkov <lemenkov@gmail.com> - 1.3.2-2
- Rebuild with new Erlang
- Hopefully fix #986623

* Tue Aug 06 2013 Peter Lemenkov <lemenkov@gmail.com> - 1.3.2-1
- Ver. 1.3.2
- Raised a number of opened files/sockets to 16384
- Install nodetool into _bindir/
- Don't use versioned path to escript to simplify updates in the future
- Use systemd macros

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Apr 08 2013 Peter Lemenkov <lemenkov@gmail.com> - 1.3.1-2
- Fix broken lager config

* Sat Apr 06 2013 Peter Lemenkov <lemenkov@gmail.com> - 1.3.1-1
- Ver. 1.3.1

* Sun Mar 24 2013 Peter Lemenkov <lemenkov@gmail.com> - 1.3.1-0.1.rc1
- Ver. 1.3.1rc1

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Nov 18 2012 Peter Lemenkov <lemenkov@gmail.com> - 1.2.1-1
- Ver. 1.2.1

* Tue Aug 14 2012 Peter Lemenkov <lemenkov@gmail.com> - 1.1.4-2
- Fixed lots of packaging issues (thanks to Ankur Sinha for noticing them)

* Fri Jul 20 2012 Peter Lemenkov <lemenkov@gmail.com> - 1.1.4-1
- Ver. 1.1.4

* Wed Oct 13 2010 Peter Lemenkov <lemenkov@gmail.com> - 0.13.0-1
- Initial build

